@@ -46,7 +46,7 @@ usage() {
 function git_clone() {
   echo "Clone the source"
   # clone source
-  git clone https://gitbox.apache.org/repos/asf/zeppelin.git "${WORKING_DIR}/zeppelin"
+  git clone https://github.com/apache/zeppelin "${WORKING_DIR}/zeppelin"
 
   if [[ $? -ne 0 ]]; then
     echo "Can not clone source repository"
