@@ -46,7 +46,7 @@ if [[ $RELEASE_VERSION == *"SNAPSHOT"* ]]; then
   DO_SNAPSHOT="yes"
 fi
 
-PUBLISH_PROFILES="-Ppublish-distr -Phadoop-2.6 -Pweb-angular"
+PUBLISH_PROFILES="-Ppublish-distr -Pweb-angular"
 PROJECT_OPTIONS="-pl !zeppelin-distribution -Dmaven.javadoc.skip=true"
 NEXUS_STAGING="https://repository.apache.org/service/local/staging"
 NEXUS_PROFILE="153446d1ac37c4"
@@ -84,20 +84,16 @@ function publish_snapshot_to_maven() {
 
   tmp_repo="$(mktemp -d /tmp/zeppelin-repo-XXXXX)"
 
-  mvn versions:set -DnewVersion=$RELEASE_VERSION
+  ./mvnw versions:set -DnewVersion=$RELEASE_VERSION
   tmp_settings="tmp-settings.xml"
   echo "<settings><servers><server>" > $tmp_settings
   echo "<id>apache.snapshots.https</id><username>$ASF_USERID</username>" >> $tmp_settings
   echo "<password>$ASF_PASSWORD</password>" >> $tmp_settings
   echo "</server></servers></settings>" >> $tmp_settings
 
-  mvn --settings $tmp_settings -Dmaven.repo.local="${tmp_repo}" -Pbeam -DskipTests \
+  ./mvnw --settings $tmp_settings -Dmaven.repo.local="${tmp_repo}" -DskipTests \
     $PUBLISH_PROFILES -Drat.skip=true deploy
 
-  "${BASEDIR}/change_scala_version.sh" 2.11
-  mvn -Pscala-2.11 --settings $tmp_settings -Dmaven.repo.local="${tmp_repo}" -Pbeam -DskipTests \
-    $PUBLISH_PROFILES -Drat.skip=true clean deploy
-
   rm $tmp_settings
   rm -rf $tmp_repo
 }
@@ -106,7 +102,7 @@ function publish_to_maven() {
   cd "${WORKING_DIR}/zeppelin"
 
   # Force release version
-  mvn versions:set -DnewVersion="${RELEASE_VERSION}"
+  ./mvnw versions:set -DnewVersion="${RELEASE_VERSION}"
 
   # Using Nexus API documented here:
   # https://support.sonatype.com/hc/en-us/articles/213465868-Uploading-to-a-Staging-Repository-via-REST-API
@@ -128,9 +124,9 @@ function publish_to_maven() {
   rm -rf $HOME/.m2/repository/org/apache/zeppelin
 
   # build with scala-2.11
-  echo "mvn clean install -DskipTests \
+  echo "./mvnw clean install -DskipTests \
     ${PUBLISH_PROFILES} ${PROJECT_OPTIONS}"
-  mvn clean install -DskipTests \
+  ./mvnw clean install -DskipTests \
     ${PUBLISH_PROFILES} ${PROJECT_OPTIONS}
   if [[ $? -ne 0 ]]; then
     echo "Build failed."
