@@ -31,16 +31,16 @@ import org.apache.zeppelin.interpreter.InterpreterResult;
 import org.apache.zeppelin.interpreter.InterpreterResultMessage;
 import org.apache.zeppelin.interpreter.remote.RemoteInterpreterEventClient;
 import org.apache.zeppelin.interpreter.thrift.InterpreterCompletion;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Ignore;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
 
 import java.io.IOException;
 import java.util.List;
 
-import static junit.framework.TestCase.assertTrue;
-import static org.junit.Assert.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.mockito.Mockito.mock;
 
 public abstract class BasePythonInterpreterTest extends ConcurrentTestCase {
@@ -49,13 +49,12 @@ public abstract class BasePythonInterpreterTest extends ConcurrentTestCase {
   protected Interpreter interpreter;
   protected boolean isPython2;
 
-  @Before
+  @BeforeEach
   public abstract void setUp() throws InterpreterException;
 
-  @After
+  @AfterEach
   public abstract void tearDown() throws InterpreterException;
 
-
   @Test
   public void testPythonBasics() throws InterpreterException, InterruptedException, IOException {
 
@@ -173,7 +172,8 @@ public abstract class BasePythonInterpreterTest extends ConcurrentTestCase {
         "from __future__ import print_function\n" +
             "def greet(name):\n" +
             "    print('Hello', name)\n" +
-            "greet('Jack')", context);
+            "greet('Jack')",
+        context);
     Thread.sleep(100);
     assertEquals(InterpreterResult.Code.SUCCESS, result.code());
     interpreterResultMessages = context.out.toInterpreterResultMessage();
@@ -208,7 +208,7 @@ public abstract class BasePythonInterpreterTest extends ConcurrentTestCase {
     // multiple text output
     context = getInterpreterContext();
     result = interpreter.interpret(
-            "for i in range(1,4):\n" + "\tprint(i)", context);
+        "for i in range(1,4):\n" + "\tprint(i)", context);
     assertEquals(InterpreterResult.Code.SUCCESS, result.code());
     interpreterResultMessages = context.out.toInterpreterResultMessage();
     assertEquals(1, interpreterResultMessages.size());
@@ -303,14 +303,30 @@ public abstract class BasePythonInterpreterTest extends ConcurrentTestCase {
     context = getInterpreterContext();
     result = interpreter.interpret("import pandas as pd\n" +
         "df = pd.DataFrame({'id':[1,2,3], 'name':['a\ta','b\\nb','c\\r\\nc']})\nz.show(df)",
-            context);
-    assertEquals(context.out.toInterpreterResultMessage().toString(),
-            InterpreterResult.Code.SUCCESS, result.code());
+        context);
+    assertEquals(InterpreterResult.Code.SUCCESS, result.code(),
+        context.out.toInterpreterResultMessage().toString());
     interpreterResultMessages = context.out.toInterpreterResultMessage();
     assertEquals(1, interpreterResultMessages.size());
     assertEquals(InterpreterResult.Type.TABLE, interpreterResultMessages.get(0).getType());
     assertEquals("id\tname\n1\ta a\n2\tb b\n3\tc c\n", interpreterResultMessages.get(0).getData());
 
+    // Pandas DataFrame with sub type
+    context = getInterpreterContext();
+    result = interpreter.interpret("import pandas as pd\n" +
+        "class ExtendedDataFrame(pd.DataFrame):\n" +
+        "  pass\n" +
+        "df = ExtendedDataFrame({'id':[1,2,3], 'name':['a\ta','b\\nb','c\\r\\nc']})\n" +
+        "z.show(df)",
+        context);
+    assertEquals(InterpreterResult.Code.SUCCESS, result.code(),
+        context.out.toInterpreterResultMessage().toString());
+    interpreterResultMessages = context.out.toInterpreterResultMessage();
+    assertEquals(1, interpreterResultMessages.size());
+    assertEquals(InterpreterResult.Type.TABLE, interpreterResultMessages.get(0).getType());
+    assertEquals("id\tname\n1\ta a\n2\tb b\n3\tc c\n", interpreterResultMessages.get(0).getData());
+
+    // Pandas DataFrame limited to three results
     context = getInterpreterContext();
     result = interpreter.interpret("import pandas as pd\n" +
         "df = pd.DataFrame({'id':[1,2,3,4], 'name':['a','b','c', 'd']})\nz.show(df)", context);
@@ -326,18 +342,36 @@ public abstract class BasePythonInterpreterTest extends ConcurrentTestCase {
     // z.show(df, show_index=True)
     context = getInterpreterContext();
     result = interpreter.interpret("import pandas as pd\n" +
-                    "df = pd.DataFrame({'id':[1,2,3], 'name':['a','b','c']})\n" +
-                    "z.show(df, show_index=True)",
-            context);
-    assertEquals(context.out.toInterpreterResultMessage().toString(),
-            InterpreterResult.Code.SUCCESS, result.code());
+        "df = pd.DataFrame({'id':[1,2,3], 'name':['a','b','c']})\n" +
+        "z.show(df, show_index=True)",
+        context);
+    assertEquals(InterpreterResult.Code.SUCCESS, result.code(),
+        context.out.toInterpreterResultMessage().toString());
     interpreterResultMessages = context.out.toInterpreterResultMessage();
     assertEquals(1, interpreterResultMessages.size());
     assertEquals(InterpreterResult.Type.TABLE, interpreterResultMessages.get(0).getType());
     assertEquals("\tid\tname\n" +
-            "%html <strong>0</strong>\t1\ta\n" +
-            "%html <strong>1</strong>\t2\tb\n" +
-            "%html <strong>2</strong>\t3\tc\n", interpreterResultMessages.get(0).getData());
+        "%html <strong>0</strong>\t1\ta\n" +
+        "%html <strong>1</strong>\t2\tb\n" +
+        "%html <strong>2</strong>\t3\tc\n", interpreterResultMessages.get(0).getData());
+
+    // z.show(df, show_index=True), index is timestamp
+    context = getInterpreterContext();
+    result = interpreter.interpret("import pandas as pd\n" +
+        "idx = pd.date_range('20230530', periods=3, freq='D')\n" +
+        "df = pd.DataFrame({'name':['a','b','c']}, index= idx)\n" +
+        "z.show(df, show_index=True)",
+        context);
+    assertEquals(InterpreterResult.Code.SUCCESS, result.code(),
+        context.out.toInterpreterResultMessage().toString());
+    interpreterResultMessages = context.out.toInterpreterResultMessage();
+    assertEquals(1, interpreterResultMessages.size());
+    assertEquals(InterpreterResult.Type.TABLE, interpreterResultMessages.get(0).getType());
+    assertEquals("\tname\n" +
+        "%html <strong>2023-05-30T00:00:00.000000000</strong>\ta\n" +
+        "%html <strong>2023-05-31T00:00:00.000000000</strong>\tb\n" +
+        "%html <strong>2023-06-01T00:00:00.000000000</strong>\tc\n",
+        interpreterResultMessages.get(0).getData());
 
     // z.show(matplotlib)
     context = getInterpreterContext();
@@ -355,7 +389,7 @@ public abstract class BasePythonInterpreterTest extends ConcurrentTestCase {
     assertEquals("%text world\n", context.out.getCurrentOutput().toString());
   }
 
-  @Ignore("Flaky test, need to investigate why it fails")
+  @Disabled("Flaky test, need to investigate why it fails")
   public void testRedefinitionZeppelinContext() throws InterpreterException {
     String redefinitionCode = "z = 1\n";
     String restoreCode = "z = __zeppelin__\n";
@@ -363,40 +397,40 @@ public abstract class BasePythonInterpreterTest extends ConcurrentTestCase {
 
     InterpreterContext context = getInterpreterContext();
     InterpreterResult result = interpreter.interpret(validCode, context);
-    assertEquals(context.out.toString() + ", " + result.toString(),
-            InterpreterResult.Code.SUCCESS, result.code());
+    assertEquals(InterpreterResult.Code.SUCCESS, result.code(),
+        context.out.toString() + ", " + result.toString());
 
     context = getInterpreterContext();
     result = interpreter.interpret(redefinitionCode, context);
-    assertEquals(context.out.toString() + ", " + result.toString(),
-            InterpreterResult.Code.SUCCESS, result.code());
+    assertEquals(InterpreterResult.Code.SUCCESS, result.code(),
+        context.out.toString() + ", " + result.toString());
 
     context = getInterpreterContext();
     result = interpreter.interpret(validCode, context);
-    assertEquals(context.out.toString() + ", " + result.toString(),
-            InterpreterResult.Code.ERROR, result.code());
+    assertEquals(InterpreterResult.Code.ERROR, result.code(),
+        context.out.toString() + ", " + result.toString());
 
     context = getInterpreterContext();
     result = interpreter.interpret(restoreCode, context);
-    assertEquals(context.out.toString() + ", " + result.toString(),
-            InterpreterResult.Code.SUCCESS, result.code());
+    assertEquals(InterpreterResult.Code.SUCCESS, result.code(),
+        context.out.toString() + ", " + result.toString());
 
     context = getInterpreterContext();
     result = interpreter.interpret("type(__zeppelin__)", context);
     System.out.println("result: " + context.out.toString() + ", " + result.toString());
-    assertEquals(context.out.toString() + ", " + result.toString(),
-            InterpreterResult.Code.SUCCESS, result.code());
+    assertEquals(InterpreterResult.Code.SUCCESS, result.code(),
+        context.out.toString() + ", " + result.toString());
 
     context = getInterpreterContext();
     result = interpreter.interpret("type(z)", context);
     System.out.println("result2: " + context.out.toString() + ", " + result.toString());
-    assertEquals(context.out.toString() + ", " + result.toString(),
-            InterpreterResult.Code.SUCCESS, result.code());
+    assertEquals(InterpreterResult.Code.SUCCESS, result.code(),
+        context.out.toString() + ", " + result.toString());
 
     context = getInterpreterContext();
     result = interpreter.interpret(validCode, context);
-    assertEquals(context.out.toString() + ", " + result.toString(),
-            InterpreterResult.Code.SUCCESS, result.code());
+    assertEquals(InterpreterResult.Code.SUCCESS, result.code(),
+        context.out.toString() + ", " + result.toString());
   }
 
   protected InterpreterContext getInterpreterContext() {
