@@ -37,7 +37,7 @@ public class FIFOScheduler extends AbstractScheduler {
   }
 
   @Override
-  public void runJobInScheduler(final Job job) {
+  public void runJobInScheduler(final Job<?> job) {
     // run job in the SingleThreadExecutor since this is FIFO.
     executor.execute(() -> runJob(job));
   }
