@@ -17,9 +17,9 @@
 
 package org.apache.zeppelin.interpreter.launcher;
 
-import org.junit.Test;
+import static org.junit.jupiter.api.Assertions.assertEquals;
 
-import static org.junit.Assert.assertEquals;
+import org.junit.jupiter.api.Test;
 
 public class InterpreterLauncherTest {
 
