@@ -1,12 +1,30 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
 package org.apache.zeppelin.interpreter.launcher;
 
 import java.io.IOException;
 import java.util.Map;
 
-import org.apache.zeppelin.interpreter.remote.RemoteInterpreterManagedProcess;
+import org.apache.zeppelin.interpreter.remote.ExecRemoteInterpreterProcess;
 import org.apache.zeppelin.interpreter.remote.RemoteInterpreterUtils;
 
-public class ClusterInterpreterProcess extends RemoteInterpreterManagedProcess {
+public class ClusterInterpreterProcess extends ExecRemoteInterpreterProcess {
 
   public ClusterInterpreterProcess(
       String intpRunner,
@@ -22,8 +40,7 @@ public class ClusterInterpreterProcess extends RemoteInterpreterManagedProcess {
       String interpreterGroupId,
       boolean isUserImpersonated) {
 
-    super(intpRunner,
-      intpEventServerPort,
+    super(intpEventServerPort,
       intpEventServerHost,
       interpreterPortRange,
       intpDir,
@@ -33,7 +50,8 @@ public class ClusterInterpreterProcess extends RemoteInterpreterManagedProcess {
       connectionPoolSize,
       interpreterSettingName,
       interpreterGroupId,
-      isUserImpersonated);
+      isUserImpersonated,
+      intpRunner);
   }
 
   @Override
