@@ -24,12 +24,11 @@ import java.io.File;
 import java.io.FileInputStream;
 import java.io.IOException;
 import java.io.InputStream;
-import java.net.SocketException;
 import java.net.URI;
 import java.net.URL;
-import java.net.UnknownHostException;
 import java.nio.charset.StandardCharsets;
 import java.nio.file.Files;
+import java.nio.file.Paths;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Date;
@@ -37,7 +36,6 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Properties;
-import java.util.TimeZone;
 import java.util.concurrent.atomic.AtomicBoolean;
 
 import com.spotify.docker.client.DefaultDockerClient;
@@ -56,6 +54,7 @@ import org.apache.commons.io.FileUtils;
 import org.apache.commons.io.filefilter.FileFilterUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.zeppelin.conf.ZeppelinConfiguration;
+import org.apache.zeppelin.conf.ZeppelinConfiguration.ConfVars;
 import org.apache.zeppelin.interpreter.launcher.utils.TarFileEntry;
 import org.apache.zeppelin.interpreter.launcher.utils.TarUtils;
 import org.apache.zeppelin.interpreter.remote.RemoteInterpreterProcess;
@@ -67,7 +66,7 @@ import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.apache.zeppelin.conf.ZeppelinConfiguration.ConfVars.ZEPPELIN_SERVER_KERBEROS_KEYTAB;
 
 public class DockerInterpreterProcess extends RemoteInterpreterProcess {
-  private static final Logger LOGGER = LoggerFactory.getLogger(DockerInterpreterLauncher.class);
+  private static final Logger LOGGER = LoggerFactory.getLogger(DockerInterpreterProcess.class);
 
   private String dockerIntpServicePort = "0";
 
@@ -99,13 +98,12 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
   private String zeppelinHome;
 
   @VisibleForTesting
-  final String CONTAINER_SPARK_HOME;
+  final String containerSparkHome;
 
   @VisibleForTesting
-  final String DOCKER_HOST;
+  final String dockerHost;
 
-  private String containerId;
-  final String CONTAINER_UPLOAD_TAR_DIR = "/tmp/zeppelin-tar";
+  private static final String CONTAINER_UPLOAD_TAR_DIR = "/tmp/zeppelin-tar";
 
   public DockerInterpreterProcess(
       ZeppelinConfiguration zconf,
@@ -127,27 +125,21 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
     this.interpreterGroupName = interpreterGroupName;
     this.interpreterSettingName = interpreterSettingName;
     this.properties = properties;
-    this.envs = new HashMap(envs);
+    this.envs = new HashMap<>(envs);
 
     this.zconf = zconf;
     this.containerName = interpreterGroupId.toLowerCase();
 
-    String sparkHome = System.getenv("CONTAINER_SPARK_HOME");
-    CONTAINER_SPARK_HOME = (sparkHome == null) ?  "/spark" : sparkHome;
-
-    String uploadLocalLib = System.getenv("UPLOAD_LOCAL_LIB_TO_CONTAINTER");
-    if (null != uploadLocalLib && StringUtils.equals(uploadLocalLib, "false")) {
-      uploadLocalLibToContainter = false;
-    }
+    containerSparkHome = zconf.getString(ConfVars.ZEPPELIN_DOCKER_CONTAINER_SPARK_HOME);
+    uploadLocalLibToContainter = zconf.getBoolean(
+        ConfVars.ZEPPELIN_DOCKER_UPLOAD_LOCAL_LIB_TO_CONTAINTER);
 
     try {
       this.zeppelinHome = getZeppelinHome();
     } catch (IOException e) {
       LOGGER.error(e.getMessage(), e);
     }
-    String defDockerHost = "http://0.0.0.0:2375";
-    String dockerHost = System.getenv("DOCKER_HOST");
-    DOCKER_HOST = (dockerHost == null) ?  defDockerHost : dockerHost;
+    dockerHost = zconf.getString(ConfVars.ZEPPELIN_DOCKER_HOST);
   }
 
   @Override
@@ -162,7 +154,7 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
 
   @Override
   public void start(String userName) throws IOException {
-    docker = DefaultDockerClient.builder().uri(URI.create(DOCKER_HOST)).build();
+    docker = DefaultDockerClient.builder().uri(URI.create(dockerHost)).build();
 
     removeExistContainer(containerName);
 
@@ -229,7 +221,7 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
 
       final ContainerCreation containerCreation
           = docker.createContainer(containerConfig, containerName);
-      this.containerId = containerCreation.id();
+      String containerId = containerCreation.id();
 
       // Start container
       docker.startContainer(containerId);
@@ -238,32 +230,37 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
 
       execInContainer(containerId, dockerCommand, false);
     } catch (DockerException e) {
-      LOGGER.error(e.getMessage(), e);
-      throw new IOException(e.getMessage());
+      throw new IOException(e);
     } catch (InterruptedException e) {
-      LOGGER.error(e.getMessage(), e);
-      throw new IOException(e.getMessage());
+      // Restore interrupted state...
+      Thread.currentThread().interrupt();
+      throw new IOException("Docker preparations were interrupted.", e);
     }
 
     long startTime = System.currentTimeMillis();
-
+    long timeoutTime = startTime + getConnectTimeout();
     // wait until interpreter send dockerStarted message through thrift rpc
     synchronized (dockerStarted) {
-      if (!dockerStarted.get()) {
+      while (!dockerStarted.get() && !Thread.currentThread().isInterrupted()) {
+        long timeToTimeout = timeoutTime - System.currentTimeMillis();
+        if (timeToTimeout <= 0) {
+          LOGGER.info("Interpreter docker creation is time out in {} seconds",
+              getConnectTimeout() / 1000);
+          stop();
+          throw new IOException(
+              "Launching zeppelin interpreter on docker is time out, kill it now");
+        }
         try {
-          dockerStarted.wait(getConnectTimeout());
+          dockerStarted.wait(timeToTimeout);
         } catch (InterruptedException e) {
-          LOGGER.error("Remote interpreter is not accessible");
-          throw new IOException(e.getMessage());
+          // Restore interrupted state...
+          Thread.currentThread().interrupt();
+          stop();
+          throw new IOException("Remote interpreter is not accessible", e);
         }
       }
     }
 
-    if (!dockerStarted.get()) {
-      LOGGER.info("Interpreter docker creation is time out in {} seconds",
-          getConnectTimeout() / 1000);
-    }
-
     // waits for interpreter thrift rpc server ready
     while (System.currentTimeMillis() - startTime < getConnectTimeout()) {
       if (RemoteInterpreterUtils.checkIfRemoteEndpointAccessible(getHost(), getPort())) {
@@ -273,6 +270,8 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
           Thread.sleep(1000);
         } catch (InterruptedException e) {
           LOGGER.error(e.getMessage(), e);
+          // Restore interrupted state...
+          Thread.currentThread().interrupt();
         }
       }
     }
@@ -285,12 +284,12 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
     LOGGER.info("Interpreter container created {}:{}", containerHost, containerPort);
     synchronized (dockerStarted) {
       dockerStarted.set(true);
-      dockerStarted.notify();
+      dockerStarted.notifyAll();
     }
   }
 
   @VisibleForTesting
-  Properties getTemplateBindings() throws IOException {
+  Properties getTemplateBindings() {
     Properties dockerProperties = new Properties();
 
     // docker template properties
@@ -312,19 +311,15 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
   }
 
   @VisibleForTesting
-  List<String> getListEnvs() throws SocketException, UnknownHostException {
+  List<String> getListEnvs() {
     // environment variables
     envs.put("ZEPPELIN_HOME", zeppelinHome);
     envs.put("ZEPPELIN_CONF_DIR", zeppelinHome + "/conf");
     envs.put("ZEPPELIN_FORCE_STOP", "true");
-    envs.put("SPARK_HOME", this.CONTAINER_SPARK_HOME);
+    envs.put("SPARK_HOME", this.containerSparkHome);
 
     // set container time zone
-    String dockerTimeZone = System.getenv("DOCKER_TIME_ZONE");
-    if (StringUtils.isBlank(dockerTimeZone)) {
-      dockerTimeZone = TimeZone.getDefault().getID();
-    }
-    envs.put("TZ", dockerTimeZone);
+    envs.put("TZ", zconf.getString(ConfVars.ZEPPELIN_DOCKER_TIME_ZONE));
 
     List<String> listEnv = new ArrayList<>();
     for (Map.Entry<String, String> entry : this.envs.entrySet()) {
@@ -344,7 +339,7 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
           return null;
         });
       } catch (Exception e) {
-        LOGGER.warn("ignore the exception when shutting down", e);
+        LOGGER.warn("Ignore the exception when shutting down", e);
       }
     }
     try {
@@ -353,7 +348,11 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
 
       // Remove container
       docker.removeContainer(containerName);
-    } catch (DockerException | InterruptedException e) {
+    } catch (InterruptedException e) {
+      LOGGER.error(e.getMessage(), e);
+      // Restore interrupted state...
+      Thread.currentThread().interrupt();
+    } catch (DockerException e) {
       LOGGER.error(e.getMessage(), e);
     }
 
@@ -379,18 +378,26 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
         }
       }
 
-      if (isExist == true) {
+      if (isExist) {
         LOGGER.info("kill exist container {}", containerName);
         docker.killContainer(containerName);
       }
-    } catch (DockerException | InterruptedException e) {
+    } catch (InterruptedException e) {
+      LOGGER.error(e.getMessage(), e);
+      // Restore interrupted state...
+      Thread.currentThread().interrupt();
+    } catch (DockerException e) {
       LOGGER.error(e.getMessage(), e);
     } finally {
       try {
-        if (isExist == true) {
+        if (isExist) {
           docker.removeContainer(containerName);
         }
-      } catch (DockerException | InterruptedException e) {
+      } catch (InterruptedException e) {
+        LOGGER.error(e.getMessage(), e);
+        // Restore interrupted state...
+        Thread.currentThread().interrupt();
+      } catch (DockerException e) {
         LOGGER.error(e.getMessage(), e);
       }
     }
@@ -406,6 +413,12 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
     return containerPort;
   }
 
+  @Override
+  public boolean isAlive() {
+    //TODO(ZEPPELIN-5876): Implement it more accurately
+    return isRunning();
+  }
+
   @Override
   public boolean isRunning() {
     if (RemoteInterpreterUtils.checkIfRemoteEndpointAccessible(getHost(), getPort())) {
@@ -474,15 +487,14 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
       // 3.5) jdbc interpreter properties keytab file
       intpKeytab = properties.getProperty("zeppelin.jdbc.keytab.location", "");
     }
-    if (!StringUtils.isBlank(intpKeytab) && !copyFiles.containsKey(intpKeytab)) {
+    if (!StringUtils.isBlank(intpKeytab)) {
       LOGGER.info("intpKeytab : {}", intpKeytab);
-      copyFiles.put(intpKeytab, intpKeytab);
+      copyFiles.putIfAbsent(intpKeytab, intpKeytab);
     }
     // 3.6) zeppelin server keytab file
     String zeppelinServerKeytab = zconf.getString(ZEPPELIN_SERVER_KERBEROS_KEYTAB);
-    if (!StringUtils.isBlank(zeppelinServerKeytab)
-        && !copyFiles.containsKey(zeppelinServerKeytab)) {
-      copyFiles.put(zeppelinServerKeytab, zeppelinServerKeytab);
+    if (!StringUtils.isBlank(zeppelinServerKeytab)) {
+      copyFiles.putIfAbsent(zeppelinServerKeytab, zeppelinServerKeytab);
     }
 
     // 4) hadoop conf dir
@@ -494,10 +506,10 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
     // 5) spark conf dir
     if (envs.containsKey("SPARK_CONF_DIR")) {
       String sparkConfDir = envs.get("SPARK_CONF_DIR");
-      rmInContainer(containerId, CONTAINER_SPARK_HOME + "/conf");
-      mkdirInContainer(containerId, CONTAINER_SPARK_HOME + "/conf");
-      copyFiles.put(sparkConfDir, CONTAINER_SPARK_HOME + "/conf");
-      envs.put("SPARK_CONF_DIR", CONTAINER_SPARK_HOME + "/conf");
+      rmInContainer(containerId, containerSparkHome + "/conf");
+      mkdirInContainer(containerId, containerSparkHome + "/conf");
+      copyFiles.put(sparkConfDir, containerSparkHome + "/conf");
+      envs.put("SPARK_CONF_DIR", containerSparkHome + "/conf");
     }
 
     if (uploadLocalLibToContainter){
@@ -523,9 +535,8 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
           FileFilterUtils.suffixFileFilter("jar"), null);
       for (File jarfile : listFiles) {
         String jarfilePath = jarfile.getAbsolutePath();
-        if (!StringUtils.isBlank(jarfilePath)
-            && !copyFiles.containsKey(jarfilePath)) {
-          copyFiles.put(jarfilePath, jarfilePath);
+        if (!StringUtils.isBlank(jarfilePath)) {
+          copyFiles.putIfAbsent(jarfilePath, jarfilePath);
         }
       }
     }
@@ -542,19 +553,15 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
     String tarFile = file2Tar(copyFiles);
 
     // copy tar to ZEPPELIN_CONTAINER_DIR, auto unzip
-    InputStream inputStream = new FileInputStream(tarFile);
-    try {
+    try (InputStream inputStream = new FileInputStream(tarFile)) {
       docker.copyToContainer(inputStream, containerId, CONTAINER_UPLOAD_TAR_DIR);
-    } finally {
-      inputStream.close();
     }
 
     // copy all files in CONTAINER_UPLOAD_TAR_DIR to the root directory
     cpdirInContainer(containerId, CONTAINER_UPLOAD_TAR_DIR + "/*", "/");
 
     // delete tar file in the local
-    File fileTar = new File(tarFile);
-    fileTar.delete();
+    Files.delete(Paths.get(tarFile));
   }
 
   private void mkdirInContainer(String containerId, String path)
@@ -578,7 +585,7 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
   private void execInContainer(String containerId, String execCommand, boolean logout)
       throws DockerException, InterruptedException {
 
-    LOGGER.info("exec container commmand: " + execCommand);
+    LOGGER.info("exec container commmand: {}", execCommand);
 
     final String[] command = {"sh", "-c", execCommand};
     final ExecCreation execCreation = docker.execCreate(
@@ -617,15 +624,10 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
   }
 
   private String getZeppelinHome() throws IOException {
-    String zeppelinHome = zconf.getZeppelinHome();
-    if (System.getenv("ZEPPELIN_HOME") != null) {
-      zeppelinHome = System.getenv("ZEPPELIN_HOME");
-    }
-
     // check zeppelinHome is exist
-    File fileZeppelinHome = new File(zeppelinHome);
+    File fileZeppelinHome = new File(zconf.getZeppelinHome());
     if (fileZeppelinHome.exists() && fileZeppelinHome.isDirectory()) {
-      return zeppelinHome;
+      return zconf.getZeppelinHome();
     }
 
     throw new IOException("Can't find zeppelin home path!");
