@@ -17,12 +17,12 @@
 
 package org.apache.zeppelin.interpreter.launcher;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
 import java.io.File;
 import java.io.IOException;
@@ -36,26 +36,26 @@ import java.util.concurrent.Executors;
 import java.util.concurrent.TimeUnit;
 
 import org.apache.zeppelin.interpreter.remote.RemoteInterpreterManagedProcess;
-import org.junit.Rule;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
+
 import io.fabric8.kubernetes.api.model.Pod;
 import io.fabric8.kubernetes.api.model.PodStatus;
 import io.fabric8.kubernetes.client.KubernetesClient;
-import io.fabric8.kubernetes.client.server.mock.KubernetesServer;
+import io.fabric8.kubernetes.client.server.mock.EnableKubernetesMockClient;
 
-public class K8sRemoteInterpreterProcessTest {
+@EnableKubernetesMockClient(https = false, crud = true)
+class K8sRemoteInterpreterProcessTest {
 
-  @Rule
-  public KubernetesServer server = new KubernetesServer(false, true);
+  KubernetesClient client;
 
   @Test
-  public void testPredefinedPortNumbers() {
+  void testPredefinedPortNumbers() {
     // given
     Properties properties = new Properties();
     Map<String, String> envs = new HashMap<>();
 
     K8sRemoteInterpreterProcess intp = new K8sRemoteInterpreterProcess(
-        server.getClient(),
+        client,
         "default",
         new File(".skip"),
         "interpreter-container:1.0",
@@ -82,7 +82,7 @@ public class K8sRemoteInterpreterProcessTest {
   }
 
   @Test
-  public void testGetTemplateBindings() {
+  void testGetTemplateBindings() {
     // given
     Properties properties = new Properties();
     properties.put("my.key1", "v1");
@@ -90,7 +90,7 @@ public class K8sRemoteInterpreterProcessTest {
     envs.put("MY_ENV1", "V1");
 
     K8sRemoteInterpreterProcess intp = new K8sRemoteInterpreterProcess(
-        server.getClient(),
+        client,
         "default",
         new File(".skip"),
         "interpreter-container:1.0",
@@ -112,7 +112,7 @@ public class K8sRemoteInterpreterProcessTest {
     Properties p = intp.getTemplateBindings(null);
 
     // then
-    assertEquals("default", p.get("zeppelin.k8s.namespace"));
+    assertEquals("default", p.get("zeppelin.k8s.interpreter.namespace"));
     assertEquals(intp.getPodName(), p.get("zeppelin.k8s.interpreter.pod.name"));
     assertEquals("sh", p.get("zeppelin.k8s.interpreter.container.name"));
     assertEquals("interpreter-container:1.0", p.get("zeppelin.k8s.interpreter.container.image"));
@@ -133,18 +133,20 @@ public class K8sRemoteInterpreterProcessTest {
   }
 
   @Test
-  public void testGetTemplateBindingsForSpark() {
+  void testGetTemplateBindingsForSpark() {
     // given
     Properties properties = new Properties();
     properties.put("my.key1", "v1");
     properties.put("spark.master", "k8s://http://api");
+    properties.put("spark.jars.ivy", "my_ivy_path");
+    properties.put("spark.driver.extraJavaOptions", "-Dextra_option");
     Map<String, String> envs = new HashMap<>();
     envs.put("MY_ENV1", "V1");
     envs.put("SPARK_SUBMIT_OPTIONS", "my options");
     envs.put("SERVICE_DOMAIN", "mydomain");
 
     K8sRemoteInterpreterProcess intp = new K8sRemoteInterpreterProcess(
-        server.getClient(),
+      client,
         "default",
         new File(".skip"),
         "interpreter-container:1.0",
@@ -171,21 +173,26 @@ public class K8sRemoteInterpreterProcessTest {
 
     envs = (HashMap<String, String>) p.get("zeppelin.k8s.envs");
     assertTrue( envs.containsKey("SPARK_HOME"));
+    assertTrue( envs.containsKey("SPARK_DRIVER_EXTRAJAVAOPTIONS_CONF"));
+    String driverExtraOptions = envs.get("SPARK_DRIVER_EXTRAJAVAOPTIONS_CONF");
+    assertTrue(driverExtraOptions.contains("-Dextra_option"));
 
     String sparkSubmitOptions = envs.get("SPARK_SUBMIT_OPTIONS");
-    assertTrue(sparkSubmitOptions.startsWith("my options "));
-    assertTrue(sparkSubmitOptions.contains("spark.kubernetes.namespace=default"));
-    assertTrue(sparkSubmitOptions.contains("spark.kubernetes.driver.pod.name=" + intp.getPodName()));
-    assertTrue(sparkSubmitOptions.contains("spark.kubernetes.container.image=spark-container:1.0"));
-    assertTrue(sparkSubmitOptions.contains("spark.driver.host=" + intp.getPodName() + ".default.svc"));
-    assertTrue(sparkSubmitOptions.contains("spark.driver.port=" + intp.getSparkDriverPort()));
-    assertTrue(sparkSubmitOptions.contains("spark.blockManager.port=" + intp.getSparkBlockManagerPort()));
-    assertFalse(sparkSubmitOptions.contains("--proxy-user"));
+    assertTrue(sparkSubmitOptions.startsWith("my options"));
+    String zeppelinSparkConf = envs.get("ZEPPELIN_SPARK_CONF");
+    assertTrue(zeppelinSparkConf.contains("spark.kubernetes.namespace=default"));
+    assertTrue(zeppelinSparkConf.contains("spark.kubernetes.driver.pod.name=" + intp.getPodName()));
+    assertTrue(zeppelinSparkConf.contains("spark.kubernetes.container.image=spark-container:1.0"));
+    assertTrue(zeppelinSparkConf.contains("spark.driver.host=" + intp.getPodName() + ".default.svc"));
+    assertTrue(zeppelinSparkConf.contains("spark.driver.port=" + intp.getSparkDriverPort()));
+    assertTrue(zeppelinSparkConf.contains("spark.blockManager.port=" + intp.getSparkBlockManagerPort()));
+    assertTrue(zeppelinSparkConf.contains("spark.jars.ivy=my_ivy_path"));
+    assertFalse(zeppelinSparkConf.contains("--proxy-user"));
     assertTrue(intp.isSpark());
   }
 
   @Test
-  public void testGetTemplateBindingsForSparkWithProxyUser() {
+  void testGetTemplateBindingsForSparkWithProxyUser() {
     // given
     Properties properties = new Properties();
     properties.put("my.key1", "v1");
@@ -196,7 +203,7 @@ public class K8sRemoteInterpreterProcessTest {
     envs.put("SERVICE_DOMAIN", "mydomain");
 
     K8sRemoteInterpreterProcess intp = new K8sRemoteInterpreterProcess(
-        server.getClient(),
+      client,
         "default",
         new File(".skip"),
         "interpreter-container:1.0",
@@ -225,19 +232,20 @@ public class K8sRemoteInterpreterProcessTest {
     assertTrue( envs.containsKey("SPARK_HOME"));
 
     String sparkSubmitOptions = envs.get("SPARK_SUBMIT_OPTIONS");
-    assertTrue(sparkSubmitOptions.startsWith("my options "));
-    assertTrue(sparkSubmitOptions.contains("spark.kubernetes.namespace=default"));
-    assertTrue(sparkSubmitOptions.contains("spark.kubernetes.driver.pod.name=" + intp.getPodName()));
-    assertTrue(sparkSubmitOptions.contains("spark.kubernetes.container.image=spark-container:1.0"));
-    assertTrue(sparkSubmitOptions.contains("spark.driver.host=" + intp.getPodName() + ".default.svc"));
-    assertTrue(sparkSubmitOptions.contains("spark.driver.port=" + intp.getSparkDriverPort()));
-    assertTrue(sparkSubmitOptions.contains("spark.blockManager.port=" + intp.getSparkBlockManagerPort()));
-    assertTrue(sparkSubmitOptions.contains("--proxy-user mytestUser"));
+    assertTrue(sparkSubmitOptions.startsWith("my options"));
+    String zeppelinSparkConf = envs.get("ZEPPELIN_SPARK_CONF");
+    assertTrue(zeppelinSparkConf.contains("spark.kubernetes.namespace=default"));
+    assertTrue(zeppelinSparkConf.contains("spark.kubernetes.driver.pod.name=" + intp.getPodName()));
+    assertTrue(zeppelinSparkConf.contains("spark.kubernetes.container.image=spark-container:1.0"));
+    assertTrue(zeppelinSparkConf.contains("spark.driver.host=" + intp.getPodName() + ".default.svc"));
+    assertTrue(zeppelinSparkConf.contains("spark.driver.port=" + intp.getSparkDriverPort()));
+    assertTrue(zeppelinSparkConf.contains("spark.blockManager.port=" + intp.getSparkBlockManagerPort()));
+    assertTrue(zeppelinSparkConf.contains("--proxy-user|mytestUser"));
     assertTrue(intp.isSpark());
   }
 
   @Test
-  public void testGetTemplateBindingsForSparkWithProxyUserAnonymous() {
+  void testGetTemplateBindingsForSparkWithProxyUserAnonymous() {
     // given
     Properties properties = new Properties();
     properties.put("my.key1", "v1");
@@ -248,7 +256,7 @@ public class K8sRemoteInterpreterProcessTest {
     envs.put("SERVICE_DOMAIN", "mydomain");
 
     K8sRemoteInterpreterProcess intp = new K8sRemoteInterpreterProcess(
-        server.getClient(),
+      client,
         "default",
         new File(".skip"),
         "interpreter-container:1.0",
@@ -281,14 +289,14 @@ public class K8sRemoteInterpreterProcessTest {
   }
 
   @Test
-  public void testSparkUiWebUrlTemplate() {
+  void testSparkUiWebUrlTemplate() {
     // given
     Properties properties = new Properties();
     Map<String, String> envs = new HashMap<>();
     envs.put("SERVICE_DOMAIN", "mydomain");
 
     K8sRemoteInterpreterProcess intp = new K8sRemoteInterpreterProcess(
-        server.getClient(),
+      client,
         "default",
         new File(".skip"),
         "interpreter-container:1.0",
@@ -324,7 +332,7 @@ public class K8sRemoteInterpreterProcessTest {
   }
 
   @Test
-  public void testSparkPodResources() {
+  void testSparkPodResources() {
     // given
     Properties properties = new Properties();
     properties.put("spark.driver.memory", "1g");
@@ -333,7 +341,7 @@ public class K8sRemoteInterpreterProcessTest {
     envs.put("SERVICE_DOMAIN", "mydomain");
 
     K8sRemoteInterpreterProcess intp = new K8sRemoteInterpreterProcess(
-        server.getClient(),
+      client,
         "default",
         new File(".skip"),
         "interpreter-container:1.0",
@@ -360,7 +368,7 @@ public class K8sRemoteInterpreterProcessTest {
   }
 
   @Test
-  public void testSparkPodResourcesMemoryOverhead() {
+  void testSparkPodResourcesMemoryOverhead() {
     // given
     Properties properties = new Properties();
     properties.put("spark.driver.memory", "1g");
@@ -370,7 +378,7 @@ public class K8sRemoteInterpreterProcessTest {
     envs.put("SERVICE_DOMAIN", "mydomain");
 
     K8sRemoteInterpreterProcess intp = new K8sRemoteInterpreterProcess(
-        server.getClient(),
+        client,
         "default",
         new File(".skip"),
         "interpreter-container:1.0",
@@ -397,7 +405,7 @@ public class K8sRemoteInterpreterProcessTest {
   }
 
   @Test
-  public void testK8sStartSuccessful() throws IOException {
+  void testK8sStartSuccessful() throws IOException {
     // given
     Properties properties = new Properties();
     Map<String, String> envs = new HashMap<>();
@@ -407,7 +415,7 @@ public class K8sRemoteInterpreterProcessTest {
     File file = new File(url.getPath());
 
     K8sRemoteInterpreterProcess intp = new K8sRemoteInterpreterProcess(
-        server.getClient(),
+      client,
         "default",
         file,
         "interpreter-container:1.0",
@@ -426,14 +434,14 @@ public class K8sRemoteInterpreterProcessTest {
         true);
     ExecutorService service = Executors.newFixedThreadPool(1);
     service
-        .submit(new PodStatusSimulator(server.getClient(), intp.getNamespace(), intp.getPodName(), intp));
+      .submit(new PodStatusSimulator(client, intp.getInterpreterNamespace(), intp.getPodName(), intp));
     intp.start("TestUser");
     // then
     assertEquals("Running", intp.getPodPhase());
   }
 
   @Test
-  public void testK8sStartFailed() {
+  void testK8sStartFailed() {
     // given
     Properties properties = new Properties();
     Map<String, String> envs = new HashMap<>();
@@ -443,7 +451,7 @@ public class K8sRemoteInterpreterProcessTest {
     File file = new File(url.getPath());
 
     K8sRemoteInterpreterProcess intp = new K8sRemoteInterpreterProcess(
-        server.getClient(),
+      client,
         "default",
         file,
         "interpreter-container:1.0",
@@ -460,7 +468,7 @@ public class K8sRemoteInterpreterProcessTest {
         10,
         false,
         true);
-    PodStatusSimulator podStatusSimulator = new PodStatusSimulator(server.getClient(), intp.getNamespace(), intp.getPodName(), intp);
+    PodStatusSimulator podStatusSimulator = new PodStatusSimulator(client, intp.getInterpreterNamespace(), intp.getPodName(), intp);
     podStatusSimulator.setSecondPhase("Failed");
     podStatusSimulator.setSuccessfulStart(false);
     ExecutorService service = Executors.newFixedThreadPool(1);
@@ -474,13 +482,13 @@ public class K8sRemoteInterpreterProcessTest {
       assertNotNull(e);
       // Check that the Pod is deleted
       assertNull(
-          server.getClient().pods().inNamespace(intp.getNamespace()).withName(intp.getPodName())
+        client.pods().inNamespace(intp.getInterpreterNamespace()).withName(intp.getPodName())
               .get());
     }
   }
 
   @Test
-  public void testK8sStartTimeoutPending() throws InterruptedException {
+  void testK8sStartTimeoutPending() throws InterruptedException {
     // given
     Properties properties = new Properties();
     Map<String, String> envs = new HashMap<>();
@@ -490,7 +498,7 @@ public class K8sRemoteInterpreterProcessTest {
     File file = new File(url.getPath());
 
     K8sRemoteInterpreterProcess intp = new K8sRemoteInterpreterProcess(
-        server.getClient(),
+      client,
         "default",
         file,
         "interpreter-container:1.0",
@@ -507,7 +515,7 @@ public class K8sRemoteInterpreterProcessTest {
         10,
         false,
         false);
-    PodStatusSimulator podStatusSimulator = new PodStatusSimulator(server.getClient(), intp.getNamespace(), intp.getPodName(), intp);
+    PodStatusSimulator podStatusSimulator = new PodStatusSimulator(client, intp.getInterpreterNamespace(), intp.getPodName(), intp);
     podStatusSimulator.setFirstPhase("Pending");
     podStatusSimulator.setSecondPhase("Pending");
     podStatusSimulator.setSuccessfulStart(false);
@@ -528,7 +536,7 @@ public class K8sRemoteInterpreterProcessTest {
     // wait for a shutdown
     service.awaitTermination(10, TimeUnit.SECONDS);
     // Check that the Pod is deleted
-    assertNull(server.getClient().pods().inNamespace(intp.getNamespace())
+    assertNull(client.pods().inNamespace(intp.getInterpreterNamespace())
         .withName(intp.getPodName()).get());
 
   }
