@@ -16,12 +16,9 @@
  */
 package org.apache.zeppelin.rest.message;
 
-import com.google.gson.Gson;
-
 import java.util.List;
 import java.util.Map;
 
-import org.apache.zeppelin.common.JsonSerializable;
 import org.apache.zeppelin.dep.Dependency;
 import org.apache.zeppelin.interpreter.InterpreterOption;
 import org.apache.zeppelin.interpreter.InterpreterProperty;
@@ -29,16 +26,20 @@ import org.apache.zeppelin.interpreter.InterpreterProperty;
 /**
  * NewInterpreterSetting REST API request message.
  */
-public class NewInterpreterSettingRequest implements JsonSerializable {
-  private static final Gson gson = new Gson();
-  private String name;
-  private String group;
+public class NewInterpreterSettingRequest {
+  private final String name;
+  private final String group;
 
-  private Map<String, InterpreterProperty> properties;
-  private List<Dependency> dependencies;
-  private InterpreterOption option;
+  private final Map<String, InterpreterProperty> properties;
+  private final List<Dependency> dependencies;
+  private final InterpreterOption option;
 
-  public NewInterpreterSettingRequest() {
+  public NewInterpreterSettingRequest(String name, String group, Map<String, InterpreterProperty> properties, List<Dependency> dependencies, InterpreterOption option) {
+    this.name = name;
+    this.group = group;
+    this.properties = properties;
+    this.dependencies = dependencies;
+    this.option = option;
   }
 
   public String getName() {
@@ -60,12 +61,4 @@ public class NewInterpreterSettingRequest implements JsonSerializable {
   public InterpreterOption getOption() {
     return option;
   }
-
-  public String toJson() {
-    return gson.toJson(this);
-  }
-
-  public static NewInterpreterSettingRequest fromJson(String json) {
-    return gson.fromJson(json, NewInterpreterSettingRequest.class);
-  }
 }
