@@ -16,10 +16,6 @@
  */
 package org.apache.zeppelin.rest;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertThat;
-import static org.junit.Assert.assertTrue;
-
 import com.google.gson.Gson;
 import com.google.gson.reflect.TypeToken;
 
@@ -27,41 +23,44 @@ import org.apache.http.client.methods.CloseableHttpResponse;
 import org.apache.http.util.EntityUtils;
 import org.apache.zeppelin.helium.Helium;
 import org.apache.zeppelin.utils.TestUtils;
-import org.junit.After;
-import org.junit.AfterClass;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import java.io.IOException;
 import java.nio.charset.StandardCharsets;
-import java.util.Map;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
 
+import static org.hamcrest.MatcherAssert.assertThat;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 import org.apache.zeppelin.helium.HeliumPackage;
 import org.apache.zeppelin.helium.HeliumRegistry;
 import org.apache.zeppelin.helium.HeliumType;
 
-public class HeliumRestApiTest extends AbstractTestRestApi {
+class HeliumRestApiTest extends AbstractTestRestApi {
   private Gson gson = new Gson();
   private static Helium helium;
 
-  @BeforeClass
-  public static void init() throws Exception {
+  @BeforeAll
+  static void init() throws Exception {
     AbstractTestRestApi.startUp(HeliumRestApi.class.getSimpleName());
     helium = TestUtils.getInstance(Helium.class);
   }
 
-  @AfterClass
-  public static void destroy() throws Exception {
+  @AfterAll
+  static void destroy() throws Exception {
     AbstractTestRestApi.shutDown();
   }
 
-  @Before
-  public void setUp() throws IOException {
+  @BeforeEach
+  void setUp() throws IOException {
     HeliumTestRegistry registry = new HeliumTestRegistry("r1", "r1");
     helium.clear();
 
@@ -88,13 +87,13 @@ public class HeliumRestApiTest extends AbstractTestRestApi {
     helium.addRegistry(registry);
   }
 
-  @After
+  @AfterEach
   public void tearDown() {
     helium.clear();
   }
 
   @Test
-  public void testGetAllPackageInfo() throws IOException {
+  void testGetAllPackageInfo() throws IOException {
     CloseableHttpResponse get = httpGet("/helium/package");
     assertThat(get, isAllowed());
     Map<String, Object> resp = gson.fromJson(EntityUtils.toString(get.getEntity(), StandardCharsets.UTF_8),
@@ -108,7 +107,7 @@ public class HeliumRestApiTest extends AbstractTestRestApi {
   }
 
   @Test
-  public void testGetAllEnabledPackageInfo() throws IOException {
+  void testGetAllEnabledPackageInfo() throws IOException {
     // No enabled packages initially
     CloseableHttpResponse get1 = httpGet("/helium/enabledPackage");
     assertThat(get1, isAllowed());
@@ -134,7 +133,7 @@ public class HeliumRestApiTest extends AbstractTestRestApi {
   }
 
   @Test
-  public void testGetSinglePackageInfo() throws IOException {
+  void testGetSinglePackageInfo() throws IOException {
     String packageName = "name1";
     CloseableHttpResponse get = httpGet("/helium/package/" + packageName);
     assertThat(get, isAllowed());
@@ -149,7 +148,7 @@ public class HeliumRestApiTest extends AbstractTestRestApi {
   }
 
   @Test
-  public void testGetAllPackageConfigs() throws IOException {
+  void testGetAllPackageConfigs() throws IOException {
     CloseableHttpResponse get = httpGet("/helium/config/");
     assertThat(get, isAllowed());
     Map<String, Object> resp = gson.fromJson(EntityUtils.toString(get.getEntity(), StandardCharsets.UTF_8),
@@ -161,7 +160,7 @@ public class HeliumRestApiTest extends AbstractTestRestApi {
   }
 
   @Test
-  public void testGetPackageConfig() throws IOException {
+  void testGetPackageConfig() throws IOException {
     String packageName = "name1";
     String artifact = "artifact1";
     CloseableHttpResponse get = httpGet("/helium/config/" + packageName + "/" + artifact);
@@ -174,7 +173,7 @@ public class HeliumRestApiTest extends AbstractTestRestApi {
   }
 
   @Test
-  public void testEnableDisablePackage() throws IOException {
+  void testEnableDisablePackage() throws IOException {
     String packageName = "name1";
     CloseableHttpResponse post1 = httpPost("/helium/enable/" + packageName, "");
     assertThat(post1, isAllowed());
@@ -200,7 +199,7 @@ public class HeliumRestApiTest extends AbstractTestRestApi {
   }
 
   @Test
-  public void testVisualizationPackageOrder() throws IOException {
+  void testVisualizationPackageOrder() throws IOException {
     CloseableHttpResponse get1 = httpGet("/helium/order/visualization");
     assertThat(get1, isAllowed());
     Map<String, Object> resp1 = gson.fromJson(EntityUtils.toString(get1.getEntity(), StandardCharsets.UTF_8),
