@@ -20,14 +20,10 @@ import com.google.gson.Gson;
 
 import org.apache.http.client.methods.CloseableHttpResponse;
 import org.apache.http.util.EntityUtils;
-import org.hamcrest.CoreMatchers;
-import org.junit.AfterClass;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Ignore;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.ErrorCollector;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -35,48 +31,45 @@ import java.io.IOException;
 import java.nio.charset.StandardCharsets;
 import java.util.Map;
 
+import static org.hamcrest.MatcherAssert.assertThat;
+import static org.hamcrest.Matchers.equalTo;
+
 public class KnoxRestApiTest extends AbstractTestRestApi {
   private final String knoxCookie = "hadoop-jwt=eyJhbGciOiJSUzI1NiJ9.eyJzdWIiOiJhZG1pbiIsImlzcyI" +
           "6IktOT1hTU08iLCJleHAiOjE1MTM3NDU1MDd9.E2cWQo2sq75h0G_9fc9nWkL0SFMI5x_-Z0Zzr0NzQ86X4jfx" +
           "liWYjr0M17Bm9GfPHRRR66s7YuYXa6DLbB4fHE0cyOoQnkfJFpU_vr1xhy0_0URc5v-Gb829b9rxuQfjKe-37h" +
           "qbUdkwww2q6QQETVMvzp0rQKprUClZujyDvh0;";
 
-  @Rule
-  public ErrorCollector collector = new ErrorCollector();
-
   private static final Logger LOG = LoggerFactory.getLogger(KnoxRestApiTest.class);
 
   Gson gson = new Gson();
 
-  @BeforeClass
+  @BeforeAll
   public static void init() throws Exception {
     AbstractTestRestApi.startUpWithKnoxEnable(KnoxRestApiTest.class.getSimpleName());
   }
 
-  @AfterClass
+  @AfterAll
   public static void destroy() throws Exception {
     AbstractTestRestApi.shutDown();
   }
 
-  @Before
-  public void setUp() {
-  }
 
   @Test
-  @Ignore
-  public void testThatOtherUserCanAccessNoteIfPermissionNotSet() throws IOException {
+  @Disabled
+  void testThatOtherUserCanAccessNoteIfPermissionNotSet() throws IOException {
     CloseableHttpResponse loginWithoutCookie = httpGet("/api/security/ticket");
     Map result = gson.fromJson(EntityUtils.toString(loginWithoutCookie.getEntity(), StandardCharsets.UTF_8), Map.class);
 
-    collector.checkThat("response contains redirect URL",
-        ((Map) result.get("body")).get("redirectURL").toString(), CoreMatchers.equalTo(
+    assertThat("response contains redirect URL",
+        ((Map) result.get("body")).get("redirectURL").toString(), equalTo(
             "https://domain.example.com/gateway/knoxsso/knoxauth/login.html?originalUrl="));
 
     CloseableHttpResponse loginWithCookie = httpGet("/api/security/ticket", "", "", knoxCookie);
     result = gson.fromJson(EntityUtils.toString(loginWithCookie.getEntity(), StandardCharsets.UTF_8), Map.class);
 
-    collector.checkThat("User logged in as admin",
-        ((Map) result.get("body")).get("principal").toString(), CoreMatchers.equalTo("admin"));
+    assertThat("User logged in as admin",
+        ((Map) result.get("body")).get("principal").toString(), equalTo("admin"));
 
     System.out.println(result);
   }
