@@ -146,6 +146,11 @@ public class ExecRemoteInterpreterProcess extends RemoteInterpreterManagedProces
     return interpreterRunner;
   }
 
+  @Override
+  public boolean isAlive() {
+    return interpreterProcessLauncher != null && interpreterProcessLauncher.isAlive();
+  }
+
   @Override
   public boolean isRunning() {
     return interpreterProcessLauncher != null && interpreterProcessLauncher.isRunning();
