@@ -20,47 +20,42 @@ package org.apache.zeppelin.interpreter;
 import com.google.common.collect.Lists;
 import org.apache.zeppelin.dep.Dependency;
 import org.apache.zeppelin.dep.DependencyResolver;
-import org.apache.zeppelin.notebook.Note;
-import org.apache.zeppelin.notebook.NoteInfo;
-import org.apache.zeppelin.notebook.Notebook;
-import org.junit.Before;
-import org.junit.Test;
+import org.apache.zeppelin.user.AuthenticationInfo;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import java.io.IOException;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 
-public class InterpreterSettingTest {
+public class InterpreterSettingTest extends AbstractInterpreterTest{
 
   private static final Logger LOGGER = LoggerFactory.getLogger(InterpreterSettingTest.class);
 
   private InterpreterSettingManager interpreterSettingManager;
-  private Notebook notebook;
-  private Note note1;
-  private Note note2;
+  private String note1Id;
+  private String note2Id;
 
 
-  @Before
-  public void setUp() throws IOException {
+  @Override
+  @BeforeEach
+  public void setUp() throws Exception {
+    super.setUp();
     interpreterSettingManager = mock(InterpreterSettingManager.class);
-    notebook = mock(Notebook.class);
     when(interpreterSettingManager.getNotebook()).thenReturn(notebook);
 
-    note1 = new Note(new NoteInfo("note1", "/note_1"));
-    note2 = new Note(new NoteInfo("note2", "/note_2"));
-    when(notebook.getNote("note1")).thenReturn(note1);
-    when(notebook.getNote("note2")).thenReturn(note2);
+    note1Id = notebook.createNote("/note_1", AuthenticationInfo.ANONYMOUS);
+    note2Id = notebook.createNote("/note_2", AuthenticationInfo.ANONYMOUS);
   }
 
   @Test
@@ -86,17 +81,17 @@ public class InterpreterSettingTest {
         .create();
 
     // create default interpreter for user1 and note1
-    assertEquals(EchoInterpreter.class.getName(), interpreterSetting.getDefaultInterpreter("user1", "note1").getClassName());
+    assertEquals(EchoInterpreter.class.getName(), interpreterSetting.getDefaultInterpreter("user1", note1Id).getClassName());
 
     // create interpreter echo for user1 and note1
-    assertEquals(EchoInterpreter.class.getName(), interpreterSetting.getInterpreter("user1", "note1", "echo").getClassName());
-    assertEquals(interpreterSetting.getDefaultInterpreter("user1", "note1"), interpreterSetting.getInterpreter("user1", "note1", "echo"));
+    assertEquals(EchoInterpreter.class.getName(), interpreterSetting.getInterpreter("user1", note1Id, "echo").getClassName());
+    assertEquals(interpreterSetting.getDefaultInterpreter("user1", note1Id), interpreterSetting.getInterpreter("user1", note1Id, "echo"));
 
     // create interpreter double_echo for user1 and note1
-    assertEquals(DoubleEchoInterpreter.class.getName(), interpreterSetting.getInterpreter("user1", "note1", "double_echo").getClassName());
+    assertEquals(DoubleEchoInterpreter.class.getName(), interpreterSetting.getInterpreter("user1", note1Id, "double_echo").getClassName());
 
     // create non-existed interpreter
-    assertNull(interpreterSetting.getInterpreter("user1", "note1", "invalid_echo"));
+    assertNull(interpreterSetting.getInterpreter("user1", note1Id, "invalid_echo"));
   }
 
   @Test
@@ -120,22 +115,22 @@ public class InterpreterSettingTest {
         .create();
 
     // create default interpreter for user1 and note1
-    Interpreter interpreter = interpreterSetting.getDefaultInterpreter("user1", "note1");
+    Interpreter interpreter = interpreterSetting.getDefaultInterpreter("user1", note1Id);
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().size());
     assertEquals("test-shared_process", interpreter.getInterpreterGroup().getId());
 
     // create default interpreter for user2 and note1
-    interpreterSetting.getDefaultInterpreter("user2", "note1");
+    interpreterSetting.getDefaultInterpreter("user2", note1Id);
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().size());
 
     // create default interpreter user1 and note2
-    interpreterSetting.getDefaultInterpreter("user1", "note2");
+    interpreterSetting.getDefaultInterpreter("user1", note2Id);
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().size());
 
     // only 1 session is created, this session is shared across users and notes
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().get(0).getSessionNum());
 
-    interpreterSetting.closeInterpreters("user1", "note1");
+    interpreterSetting.closeInterpreters("user1", note1Id);
     assertEquals(0, interpreterSetting.getAllInterpreterGroups().size());
   }
 
@@ -160,22 +155,22 @@ public class InterpreterSettingTest {
         .create();
 
     // create interpreter for user1 and note1
-    Interpreter interpreter = interpreterSetting.getDefaultInterpreter("user1", "note1");
+    Interpreter interpreter = interpreterSetting.getDefaultInterpreter("user1", note1Id);
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().size());
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().get(0).getSessionNum());
     assertEquals("test-shared_process", interpreter.getInterpreterGroup().getId());
 
     // create interpreter for user2 and note1
-    interpreterSetting.getDefaultInterpreter("user2", "note1");
+    interpreterSetting.getDefaultInterpreter("user2", note1Id);
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().size());
     assertEquals(2, interpreterSetting.getAllInterpreterGroups().get(0).getSessionNum());
 
-    interpreterSetting.closeInterpreters("user1", "note1");
+    interpreterSetting.closeInterpreters("user1", note1Id);
     // InterpreterGroup is still there, but one session is removed
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().size());
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().get(0).getSessionNum());
 
-    interpreterSetting.closeInterpreters("user2", "note1");
+    interpreterSetting.closeInterpreters("user2", note1Id);
     assertEquals(0, interpreterSetting.getAllInterpreterGroups().size());
   }
 
@@ -200,22 +195,22 @@ public class InterpreterSettingTest {
         .create();
 
     // create interpreter for user1 and note1
-    Interpreter interpreter = interpreterSetting.getDefaultInterpreter("user1", "note1");
+    Interpreter interpreter = interpreterSetting.getDefaultInterpreter("user1", note1Id);
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().size());
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().get(0).getSessionNum());
     assertEquals("test-shared_process", interpreter.getInterpreterGroup().getId());
 
     // create interpreter for user1 and note2
-    interpreterSetting.getDefaultInterpreter("user1", "note2");
+    interpreterSetting.getDefaultInterpreter("user1", note2Id);
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().size());
     assertEquals(2, interpreterSetting.getAllInterpreterGroups().get(0).getSessionNum());
 
-    interpreterSetting.closeInterpreters("user1", "note1");
+    interpreterSetting.closeInterpreters("user1", note1Id);
     // InterpreterGroup is still there, but one session is removed
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().size());
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().get(0).getSessionNum());
 
-    interpreterSetting.closeInterpreters("user1", "note2");
+    interpreterSetting.closeInterpreters("user1", note2Id);
     assertEquals(0, interpreterSetting.getAllInterpreterGroups().size());
   }
 
@@ -240,13 +235,13 @@ public class InterpreterSettingTest {
         .create();
 
     // create interpreter for user1 and note1
-    Interpreter interpreter1 = interpreterSetting.getDefaultInterpreter("user1", "note1");
+    Interpreter interpreter1 = interpreterSetting.getDefaultInterpreter("user1", note1Id);
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().size());
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().get(0).getSessionNum());
     assertEquals("test-user1", interpreter1.getInterpreterGroup().getId());
 
     // create interpreter for user2 and note1
-    Interpreter interpreter2 = interpreterSetting.getDefaultInterpreter("user2", "note1");
+    Interpreter interpreter2 = interpreterSetting.getDefaultInterpreter("user2", note1Id);
     assertEquals(2, interpreterSetting.getAllInterpreterGroups().size());
     assertEquals("test-user2", interpreter2.getInterpreterGroup().getId());
 
@@ -254,9 +249,9 @@ public class InterpreterSettingTest {
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().get(0).getSessionNum());
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().get(1).getSessionNum());
 
-    interpreterSetting.closeInterpreters("user1", "note1");
+    interpreterSetting.closeInterpreters("user1", note1Id);
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().size());
-    interpreterSetting.closeInterpreters("user2", "note1");
+    interpreterSetting.closeInterpreters("user2", note1Id);
     assertEquals(0, interpreterSetting.getAllInterpreterGroups().size());
   }
 
@@ -281,23 +276,23 @@ public class InterpreterSettingTest {
         .create();
 
     // create interpreter for user1 and note1
-    Interpreter interpreter1 = interpreterSetting.getDefaultInterpreter("user1", "note1");
+    Interpreter interpreter1 = interpreterSetting.getDefaultInterpreter("user1", note1Id);
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().size());
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().get(0).getSessionNum());
-    assertEquals("test-note1", interpreter1.getInterpreterGroup().getId());
+    assertEquals("test-" + note1Id, interpreter1.getInterpreterGroup().getId());
 
     // create interpreter for user2 and note2
-    Interpreter interpreter2 = interpreterSetting.getDefaultInterpreter("user1", "note2");
+    Interpreter interpreter2 = interpreterSetting.getDefaultInterpreter("user1", note2Id);
     assertEquals(2, interpreterSetting.getAllInterpreterGroups().size());
-    assertEquals("test-note2", interpreter2.getInterpreterGroup().getId());
+    assertEquals("test-" + note2Id, interpreter2.getInterpreterGroup().getId());
 
     // Each user own one InterpreterGroup and one session per InterpreterGroup
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().get(0).getSessionNum());
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().get(1).getSessionNum());
 
-    interpreterSetting.closeInterpreters("user1", "note1");
+    interpreterSetting.closeInterpreters("user1", note1Id);
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().size());
-    interpreterSetting.closeInterpreters("user1", "note2");
+    interpreterSetting.closeInterpreters("user1", note2Id);
     assertEquals(0, interpreterSetting.getAllInterpreterGroups().size());
   }
 
@@ -323,37 +318,37 @@ public class InterpreterSettingTest {
         .create();
 
     // create interpreter for user1 and note1
-    Interpreter interpreter1 = interpreterSetting.getDefaultInterpreter("user1", "note1");
+    Interpreter interpreter1 = interpreterSetting.getDefaultInterpreter("user1", note1Id);
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().size());
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().get(0).getSessionNum());
     assertEquals("test-user1", interpreter1.getInterpreterGroup().getId());
 
-    interpreterSetting.getDefaultInterpreter("user1", "note2");
+    interpreterSetting.getDefaultInterpreter("user1", note2Id);
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().size());
     assertEquals(2, interpreterSetting.getAllInterpreterGroups().get(0).getSessionNum());
 
     // create interpreter for user2 and note1
-    Interpreter interpreter2 = interpreterSetting.getDefaultInterpreter("user2", "note1");
+    Interpreter interpreter2 = interpreterSetting.getDefaultInterpreter("user2", note1Id);
     assertEquals(2, interpreterSetting.getAllInterpreterGroups().size());
     assertEquals("test-user2", interpreter2.getInterpreterGroup().getId());
 
     // group1 for user1 has 2 sessions, and group2 for user2 has 1 session
-    assertEquals(interpreterSetting.getInterpreterGroup("user1", "note1"), interpreterSetting.getInterpreterGroup("user1", "note2"));
-    assertEquals(2, interpreterSetting.getInterpreterGroup("user1", "note1").getSessionNum());
-    assertEquals(2, interpreterSetting.getInterpreterGroup("user1", "note2").getSessionNum());
-    assertEquals(1, interpreterSetting.getInterpreterGroup("user2", "note1").getSessionNum());
+    assertEquals(interpreterSetting.getInterpreterGroup("user1", note1Id), interpreterSetting.getInterpreterGroup("user1", note2Id));
+    assertEquals(2, interpreterSetting.getInterpreterGroup("user1", note1Id).getSessionNum());
+    assertEquals(2, interpreterSetting.getInterpreterGroup("user1", note2Id).getSessionNum());
+    assertEquals(1, interpreterSetting.getInterpreterGroup("user2", note1Id).getSessionNum());
 
     // close one session for user1
-    interpreterSetting.closeInterpreters("user1", "note1");
+    interpreterSetting.closeInterpreters("user1", note1Id);
     assertEquals(2, interpreterSetting.getAllInterpreterGroups().size());
-    assertEquals(1, interpreterSetting.getInterpreterGroup("user1", "note1").getSessionNum());
+    assertEquals(1, interpreterSetting.getInterpreterGroup("user1", note1Id).getSessionNum());
 
     // close another session for user1
-    interpreterSetting.closeInterpreters("user1", "note2");
+    interpreterSetting.closeInterpreters("user1", note2Id);
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().size());
 
     // close session for user2
-    interpreterSetting.closeInterpreters("user2", "note1");
+    interpreterSetting.closeInterpreters("user2", note1Id);
     assertEquals(0, interpreterSetting.getAllInterpreterGroups().size());
   }
 
@@ -379,23 +374,23 @@ public class InterpreterSettingTest {
         .create();
 
     // create interpreter for user1 and note1
-    Interpreter interpreter1 = interpreterSetting.getDefaultInterpreter("user1", "note1");
+    Interpreter interpreter1 = interpreterSetting.getDefaultInterpreter("user1", note1Id);
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().size());
-    assertEquals("test-user1-note1", interpreter1.getInterpreterGroup().getId());
+    assertEquals("test-user1-" + note1Id, interpreter1.getInterpreterGroup().getId());
 
     // create interpreter for user1 and note2
-    Interpreter interpreter2 = interpreterSetting.getDefaultInterpreter("user1", "note2");
+    Interpreter interpreter2 = interpreterSetting.getDefaultInterpreter("user1", note2Id);
     assertEquals(2, interpreterSetting.getAllInterpreterGroups().size());
-    assertEquals("test-user1-note2", interpreter2.getInterpreterGroup().getId());
+    assertEquals("test-user1-" + note2Id, interpreter2.getInterpreterGroup().getId());
 
     // create interpreter for user2 and note1
-    Interpreter interpreter3 = interpreterSetting.getDefaultInterpreter("user2", "note1");
-    assertEquals("test-user2-note1", interpreter3.getInterpreterGroup().getId());
+    Interpreter interpreter3 = interpreterSetting.getDefaultInterpreter("user2", note1Id);
+    assertEquals("test-user2-" + note1Id, interpreter3.getInterpreterGroup().getId());
 
     // create interpreter for user2 and note2
-    Interpreter interpreter4 = interpreterSetting.getDefaultInterpreter("user2", "note2");
+    Interpreter interpreter4 = interpreterSetting.getDefaultInterpreter("user2", note2Id);
     assertEquals(4, interpreterSetting.getAllInterpreterGroups().size());
-    assertEquals("test-user2-note2", interpreter4.getInterpreterGroup().getId());
+    assertEquals("test-user2-" + note2Id, interpreter4.getInterpreterGroup().getId());
 
     for (InterpreterGroup interpreterGroup : interpreterSetting.getAllInterpreterGroups()) {
       // each InterpreterGroup has one session
@@ -403,19 +398,19 @@ public class InterpreterSettingTest {
     }
 
     // close one session for user1 and note1
-    interpreterSetting.closeInterpreters("user1", "note1");
+    interpreterSetting.closeInterpreters("user1", note1Id);
     assertEquals(3, interpreterSetting.getAllInterpreterGroups().size());
 
     // close one session for user1 and note2
-    interpreterSetting.closeInterpreters("user1", "note2");
+    interpreterSetting.closeInterpreters("user1", note2Id);
     assertEquals(2, interpreterSetting.getAllInterpreterGroups().size());
 
     // close one session for user2 and note1
-    interpreterSetting.closeInterpreters("user2", "note1");
+    interpreterSetting.closeInterpreters("user2", note1Id);
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().size());
 
     // close one session for user2 and note2
-    interpreterSetting.closeInterpreters("user2", "note2");
+    interpreterSetting.closeInterpreters("user2", note2Id);
     assertEquals(0, interpreterSetting.getAllInterpreterGroups().size());
   }
 
@@ -441,40 +436,40 @@ public class InterpreterSettingTest {
         .create();
 
     // create interpreter for user1 and note1
-    Interpreter interpreter1 = interpreterSetting.getDefaultInterpreter("user1", "note1");
+    Interpreter interpreter1 = interpreterSetting.getDefaultInterpreter("user1", note1Id);
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().size());
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().get(0).getSessionNum());
     assertEquals("test-shared_process", interpreter1.getInterpreterGroup().getId());
 
     // create interpreter for user1 and note2
-    interpreterSetting.getDefaultInterpreter("user1", "note2");
+    interpreterSetting.getDefaultInterpreter("user1", note2Id);
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().size());
     assertEquals(2, interpreterSetting.getAllInterpreterGroups().get(0).getSessionNum());
 
     // create interpreter for user2 and note1
-    interpreterSetting.getDefaultInterpreter("user2", "note1");
+    interpreterSetting.getDefaultInterpreter("user2", note1Id);
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().size());
     assertEquals(3, interpreterSetting.getAllInterpreterGroups().get(0).getSessionNum());
 
     // create interpreter for user2 and note2
-    interpreterSetting.getDefaultInterpreter("user2", "note2");
+    interpreterSetting.getDefaultInterpreter("user2", note2Id);
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().size());
     assertEquals(4, interpreterSetting.getAllInterpreterGroups().get(0).getSessionNum());
 
     // close one session for user1 and note1
-    interpreterSetting.closeInterpreters("user1", "note1");
+    interpreterSetting.closeInterpreters("user1", note1Id);
     assertEquals(3, interpreterSetting.getAllInterpreterGroups().get(0).getSessionNum());
 
     // close one session for user1 and note2
-    interpreterSetting.closeInterpreters("user1", "note2");
+    interpreterSetting.closeInterpreters("user1", note2Id);
     assertEquals(2, interpreterSetting.getAllInterpreterGroups().get(0).getSessionNum());
 
     // close one session for user2 and note1
-    interpreterSetting.closeInterpreters("user2", "note1");
+    interpreterSetting.closeInterpreters("user2", note1Id);
     assertEquals(1, interpreterSetting.getAllInterpreterGroups().get(0).getSessionNum());
 
     // close one session for user2 and note2
-    interpreterSetting.closeInterpreters("user2", "note2");
+    interpreterSetting.closeInterpreters("user2", note2Id);
     assertEquals(0, interpreterSetting.getAllInterpreterGroups().size());
   }
 
@@ -583,8 +578,9 @@ public class InterpreterSettingTest {
       Thread.sleep(1000);
       LOGGER.warn("Downloading dependency");
     }
-    assertTrue(interpreterSetting.getErrorReason(),
-            interpreterSetting.getErrorReason().contains("Cannot fetch dependencies"));
+    assertTrue(
+            interpreterSetting.getErrorReason().contains("Cannot fetch dependencies"),
+            interpreterSetting.getErrorReason());
 
     // clean dependency
     interpreterSetting.setDependencies(new ArrayList<>());
