@@ -17,8 +17,9 @@
 
 package org.apache.zeppelin.util;
 
-import org.junit.Test;
-import static org.junit.Assert.assertNotNull;
+import org.junit.jupiter.api.Test;
+
+import static org.junit.jupiter.api.Assertions.assertNotNull;
 
 public class UtilTest {
 
